Servalcat commands
==================

SPA
---

refine_spa
~~~~~~~~~~

REFMAC5 pipeline for SPA. The weighted and sharpened Fo-Fc map is calculated after the refinement. For details please see the reference.

.. literalinclude:: help/refine_spa.txt
   :language: console

fofc
~~~~

.. literalinclude:: help/fofc.txt
   :language: console

trim
~~~~

.. literalinclude:: help/trim.txt
   :language: console


Utilities
---------

TBD
